@@ -8,7 +8,7 @@ from .pixelate import pixelate
 from .blur import blur
 from .stack import stack
 from .render import render
-
+from .replace import replace
 
 
 CONTEXT_SETTINGS = dict(
@@ -23,6 +23,7 @@ def main():
     pass
 
 
+main.add_command(replace)
 main.add_command(render)
 main.add_command(stack)
 main.add_command(blur)
